Entry point for the inference layer.
Routes requests to the correct adapter based on the provider's api_format.
Summary
Functions
Returns the adapter module for the given provider.
Entry point for the inference layer.
Routes requests to the correct adapter based on the provider's api_format.
Returns the adapter module for the given provider.